@@ -22,26 +22,16 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, Task):
             return obj.__dict__
+        elif isinstance(obj, TaskMessage):
+            return obj.__dict__
         elif isinstance(obj, Product):
             return obj.__dict__
         elif isinstance(obj, Process):
             return obj.__dict__
-        elif isinstance(obj, AddProcess):
-            return obj.__dict__
-        elif isinstance(obj, MoveTask):
-            return obj.__dict__
-        elif isinstance(obj, CompleteTask):
-            return obj.__dict__
-        elif isinstance(obj, Destination):
-            return obj.value
-        elif isinstance(obj, ConfirmNeeded):
-            return obj.__dict__
-        elif isinstance(obj, ConfirmTask):
+        elif isinstance(obj, ProcessMessage):
             return obj.__dict__
         elif isinstance(obj, ProgramState):
             return obj.__dict__
-        elif isinstance(obj, TaskStatus):
-            return obj.__dict__
         elif isinstance(obj, AxisAngle):
             return obj.__dict__
         else:
@@ -72,24 +62,16 @@ class JsonDecoder(json.JSONDecoder):
                 return WaypointConfig(**obj)
             if '_type' in obj and obj['_type'] == 'task':
                 return Task(**obj)
+            if '_type' in obj and obj['_type'] == 'task_message':
+                return TaskMessage(**obj)
             if '_type' in obj and obj['_type'] == 'product':
                 return Product(**obj)
             if '_type' in obj and obj['_type'] == 'process':
                 return Process(**obj)
-            if '_type' in obj and obj['_type'] == 'add_process':
-                return AddProcess(**obj)
-            if '_type' in obj and obj['_type'] == 'move_task':
-                return MoveTask(**obj)
-            if '_type' in obj and obj['_type'] == 'complete_task':
-                return CompleteTask(**obj)
-            if '_type' in obj and obj['_type'] == 'confirm_needed':
-                return ConfirmNeeded(**obj)
-            if '_type' in obj and obj['_type'] == 'confirm_task':
-                return ConfirmTask(**obj)
+            if '_type' in obj and obj['_type'] == 'process_message':
+                return ProcessMessage(**obj)
             if '_type' in obj and obj['_type'] == 'program_state':
                 return ProgramState(**obj)
-            if '_type' in obj and obj['_type'] == 'task_status':
-                return TaskStatus(**obj)
             if '_type' in obj and obj['_type'] == 'axis_angle':
                 return AxisAngle(**obj)
         return obj
