@@ -8,14 +8,14 @@ class Test(TestCase):
 
     def test_task(self):
 
-        task = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)))
+        task = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
         task_string = json_encode(task)
         expected_string = '{"_type": "task", "uuid": "uuid", "name": "name", "product_uuid": "product_uuid", ' \
                           '"pose": {"_type": "pose", "name": "", "position": {"_type": "vector3", "x": 0.0, ' \
                           '"y": 0.0, "z": 0.0}, "rotation": {"_type": "vector3", "x": 0.0, "y": 0.0, "z": 0.0}' \
                           ', "axis_angle": {"_type": "axis_angle", "angle": 0.0, "x": 1, "y": 0, "z": 0}}, ' \
-                          '"automated": false, "assigned_to": "human", "conditions": [], "conditions_fulfilled": true, ' \
-                          '"can_undo": false, "description": "", "status": "waiting"}'
+                          '"agents": ["human"], "assigned_to": "human", "conditions": [], ' \
+                          '"conditions_fulfilled": true, "can_undo": false, "description": "", "status": "waiting"}'
 
         self.assertIs(type(task_string), str, f"Got: {type(task_string)}. Expected {str}")
         self.assertEqual(task_string, expected_string, f"Expected {expected_string}, got: {task_string}")
@@ -25,9 +25,9 @@ class Test(TestCase):
         assert task_decoded == task, "The decoded object must be equal to the encoded"
 
     def test_task_equals(self):
-        task1 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)))
-        task2 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)))
-        task3 = Task('other', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)))
+        task1 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
+        task2 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
+        task3 = Task('other', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
 
         assert task1 == task2
         assert task1 != task3
@@ -35,7 +35,7 @@ class Test(TestCase):
 
     def test_task_repr(self):
         task = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)),
-                    description="Hard task!")
+                    [Task.ASSIGNED_TO_HUMAN], description="Hard task!")
         expected, got = 'Hard task!', f'{task}'
 
         assert expected in got, f"Expected {expected} in got: {got}"
